## Arrive the spaceship
Arrive the spaceship is a frogger-like game made with Python, using the Pygame package

## Install and update
- To install the game as a python package, use the command:
```
```
- To update the game, use the command:
```
```

> Your computer must have Python 3.6 or higher, with pip command installed

## How to play

## Latest release
## License
This software is licensed under the terms of the MIT license. Please read the LICENSE file.

## Authors
This game was created and designed by [Vinícius Azevedo](https://github.com/viniciussousaazevedo) and [Carlos Fuch](https://github.com/httpcarlxs) as a university project